@@ -126,7 +126,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin to get avatars for artist and author fields",
                    "Igalia S.L.",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.igalia.com",
                    grl_gravatar_source_plugin_init,
                    NULL,
