@@ -317,7 +317,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for browsing podcasts",
                    "Igalia S.L.",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.igalia.com",
                    grl_podcasts_plugin_init,
                    NULL,
