@@ -201,7 +201,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin to retrieve movie metadata from themoviedb.org",
                    "Canonical Ltd.",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.canonical.com",
                    grl_tmdb_source_plugin_init,
                    NULL,
