@@ -228,23 +228,6 @@ grl_tracker_add_source (GrlTrackerSource *source)
                                 NULL);
 }
 
-void
-grl_tracker_del_source (GrlTrackerSource *source)
-{
-  GrlTrackerSourcePriv *priv = GRL_TRACKER_SOURCE_GET_PRIVATE (source);
-
-  GRL_DEBUG ("==================>del source '%s'",
-             grl_source_get_name (GRL_SOURCE (source)));
-
-  g_hash_table_remove (grl_tracker_source_sources,
-                       grl_tracker_source_get_tracker_source (source));
-  grl_tracker_source_cache_del_source (grl_tracker_item_cache, source);
-  priv->state = GRL_TRACKER_SOURCE_STATE_DELETED;
-  grl_registry_unregister_source (grl_registry_get_default (),
-                                  GRL_SOURCE (source),
-                                  NULL);
-}
-
 gboolean
 grl_tracker_source_can_notify (GrlTrackerSource *source)
 {
