@@ -340,25 +340,20 @@ TRACKER_QUERY_CB(GrlSourceBrowseSpec, browse, BROWSE)
 TRACKER_QUERY_CB(GrlSourceSearchSpec, search, SEARCH)
 
 static void
-tracker_resolve_cb (GObject      *source_object,
-                    GAsyncResult *result,
-                    GrlTrackerOp *os)
+tracker_resolve_result_cb (GObject      *source_object,
+                           GAsyncResult *result,
+                           GrlTrackerOp *os)
 {
-  TrackerSparqlStatement *statement = TRACKER_SPARQL_STATEMENT (source_object);
-  GrlSourceResolveSpec *rs = (GrlSourceResolveSpec *) os->data;
+  TrackerSparqlCursor  *cursor = TRACKER_SPARQL_CURSOR (source_object);
   gint                  col;
   GError               *tracker_error = NULL, *error = NULL;
-  TrackerSparqlCursor  *cursor;
+  GrlSourceResolveSpec *rs = (GrlSourceResolveSpec *) os->data;
 
   GRL_ODEBUG ("%s", __FUNCTION__);
 
-  cursor = tracker_sparql_statement_execute_finish (statement,
-                                                    result, &tracker_error);
+  if (tracker_sparql_cursor_next_finish (cursor, result, &tracker_error)) {
+    GRL_ODEBUG ("\tend of parsing id=%u :)", rs->operation_id);
 
-  if (!cursor)
-    goto end_operation;
-
-  if (tracker_sparql_cursor_next (cursor, NULL, &tracker_error)) {
     /* Translate Sparql result into Grilo result */
     for (col = 0 ; col < tracker_sparql_cursor_get_n_columns (cursor) ; col++) {
       fill_grilo_media_from_sparql (GRL_TRACKER_SOURCE (rs->source),
@@ -371,10 +366,9 @@ tracker_resolve_cb (GObject      *source_object,
     rs->callback (rs->source, rs->operation_id, rs->media, rs->user_data, NULL);
   }
 
- end_operation:
   if (tracker_error) {
-    GRL_WARNING ("Could not execute sparql resolve query : %s",
-                 tracker_error->message);
+    GRL_WARNING ("\terror in parsing resolve id=%u : %s",
+                 rs->operation_id, tracker_error->message);
 
     error = g_error_new (GRL_CORE_ERROR,
                          GRL_CORE_ERROR_RESOLVE_FAILED,
@@ -383,15 +377,58 @@ tracker_resolve_cb (GObject      *source_object,
 
     rs->callback (rs->source, rs->operation_id, rs->media, rs->user_data, error);
 
-    g_error_free (tracker_error);
+    g_clear_error (&tracker_error);
     g_error_free (error);
   }
 
   g_clear_object (&cursor);
-
   grl_tracker_op_free (os);
 }
 
+static void
+tracker_resolve_cb (GObject      *source_object,
+                    GAsyncResult *result,
+                    GrlTrackerOp *os)
+{
+  TrackerSparqlStatement *statement = TRACKER_SPARQL_STATEMENT (source_object);
+  GrlSourceResolveSpec *rs = (GrlSourceResolveSpec *) os->data;
+  GError               *tracker_error = NULL, *error = NULL;
+  TrackerSparqlCursor  *cursor;
+
+  GRL_ODEBUG ("%s", __FUNCTION__);
+
+  cursor = tracker_sparql_statement_execute_finish (statement,
+                                                    result, &tracker_error);
+
+  if (!cursor) {
+    if (tracker_error) {
+      GRL_WARNING ("Could not execute sparql resolve query : %s",
+                   tracker_error->message);
+
+      error = g_error_new (GRL_CORE_ERROR,
+                           GRL_CORE_ERROR_RESOLVE_FAILED,
+                           _("Failed to resolve: %s"),
+                           tracker_error->message);
+
+      rs->callback (rs->source, rs->operation_id, rs->media, rs->user_data, error);
+
+      g_clear_error (&tracker_error);
+      g_error_free (error);
+    } else {
+      rs->callback (rs->source, rs->operation_id, rs->media, rs->user_data, NULL);
+    }
+
+    g_clear_object (&cursor);
+    grl_tracker_op_free (os);
+
+    return;
+  }
+
+  tracker_sparql_cursor_next_async (cursor, NULL,
+                                    (GAsyncReadyCallback) tracker_resolve_result_cb,
+                                    (gpointer) os);
+}
+
 static void
 tracker_media_from_uri_cb (GObject      *source_object,
                            GAsyncResult *result,
@@ -524,51 +561,15 @@ grl_tracker_source_writable_keys (GrlSource *source)
  * Columns must be named with the Grilo key name that the column
  * represent. Unnamed or unknown columns will be ignored.
  *
- * First column must be the media type, and it does not need to be named.  It
- * must match with any value supported in rdf:type() property, or
- * grilo#Container. Types understood are:
- *
- * <itemizedlist>
- *   <listitem>
- *     <para>
- *       <literal>nmm#MusicPiece</literal>
- *     </para>
- *   </listitem>
- *   <listitem>
- *     <para>
- *       <literal>nmm#Video</literal>
- *     </para>
- *   </listitem>
- *   <listitem>
- *     <para>
- *       <literal>nmm#Photo</literal>
- *     </para>
- *   </listitem>
- *   <listitem>
- *     <para>
- *       <literal>nmm#Artist</literal>
- *     </para>
- *   </listitem>
- *   <listitem>
- *     <para>
- *       <literal>nmm#MusicAlbum</literal>
- *     </para>
- *   </listitem>
- *   <listitem>
- *     <para>
- *       <literal>grilo#Container</literal>
- *     </para>
- *   </listitem>
- * </itemizedlist>
- *
+ * First column must be grilo media enum value, and it does not need to be named.
  * An example for searching all songs:
  *
  * <informalexample>
  *   <programlisting>
- *     SELECT rdf:type(?song)
+ *     SELECT 1
  *            ?song            AS ?id
  *            nie:title(?song) AS ?title
- *            nie:url(?song)   AS ?url
+ *            nie:isStoredAs(?song) AS ?url
  *     WHERE { ?song a nmm:MusicPiece }
  *   </programlisting>
  * </informalexample>
