@@ -299,7 +299,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for browsing and searching YouTube videos",
                    "Igalia",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.igalia.com",
                    grl_youtube_plugin_init,
                    NULL,
